.. image:: https://raw.githubusercontent.com/Nagasaki45/bibo/master/logo/logo.svg
    :alt: bibo logo

Command line reference manager with a single source of truth: the ``.bib`` file. Inspired by `beets`_.

.. image:: https://github.com/Nagasaki45/bibo/actions/workflows/ci_pipeline.yml/badge.svg
  :target: https://github.com/Nagasaki45/bibo/actions/workflows/ci_pipeline.yml
  :alt: CI status

.. image:: https://codecov.io/gh/Nagasaki45/bibo/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/Nagasaki45/bibo

.. image:: https://readthedocs.org/projects/bibo/badge/?version=latest
  :target: https://bibo.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://asciinema.org/a/313768.svg
  :target: https://asciinema.org/a/313768

.. _beets: https://github.com/beetbox/beets


Links
-----

* Documentation: https://bibo.readthedocs.io/en/latest
* Source code: https://github.com/Nagasaki45/bibo
* PyPI releases: https://pypi.org/project/bibo
* License: `MIT`_

.. _MIT: https://github.com/Nagasaki45/bibo/blob/master/LICENSE
